@@ -251,16 +251,19 @@ class TestTransformers(object):
         result = to_series(statpoint_streamset)
         values = [2.0, 4.0, 6.0, 8.0]
         index = [1500000000100000000, 1500000000300000000, 1500000000500000000, 1500000000700000000]
-        assert (result[0] == Series(values, index=index)).all()
+        times = Index(index, dtype='datetime64[ns]')
+        assert (result[0] == Series(values, index=times)).all()
 
         values = [3.0, 5.0, 7.0, 9.0]
         index = [1500000000100000000, 1500000000300000000, 1500000000500000000, 1500000000700000000]
-        assert (result[1] == Series(values, index=index)).all()
+        times = Index(index, dtype='datetime64[ns]')
+        assert (result[1] == Series(values, index=times)).all()
 
         result = to_series(statpoint_streamset, agg="max")
         values = [2.5, 4.5, 6.5, 8.5]
         index = [1500000000100000000, 1500000000300000000, 1500000000500000000, 1500000000700000000]
-        assert (result[0] == Series(values, index=index)).all()
+        times = Index(index, dtype='datetime64[ns]')
+        assert (result[0] == Series(values, index=times)).all()
 
     def test_to_series_index_type(self, streamset):
         """
@@ -278,14 +281,6 @@ class TestTransformers(object):
         for series in result:
             assert series.index.dtype.name == 'int64'
 
-    def test_to_series_index_as_int(self, streamset):
-        """
-        assert datetime64_index: False produces 'int64' index
-        """
-        result = to_series(streamset, False)
-        for series in result:
-            assert series.index.dtype.name == 'int64'
-
     def test_to_series_raises_on_agg_all(self, statpoint_streamset):
         """
         asserts to_series raises error if using "all" as agg.
